Function diem_documentation_tool::update_rust_quotes [−][src]
pub fn update_rust_quotes<R>(
reader: R,
definitions: &BTreeMap<String, String>
) -> Result<String> where
R: BufRead, Expand description
Replace the markdown content in reader and return a new string, where some of the Rust quotes
have been updated to use the latest definitions.